EXPORTS
	??0CEventCallbackFilter@@IAE@XZ @ 1 NONAME ; CEventCallbackFilter::CEventCallbackFilter(void)
	??1CDriverTrans@@UAE@XZ @ 2 NONAME ; CDriverTrans::~CDriverTrans(void)
	??1CEventCallbackFilter@@UAE@XZ @ 3 NONAME ; CEventCallbackFilter::~CEventCallbackFilter(void)
	??1CWspEventDriver@@UAE@XZ @ 4 NONAME ; CWspEventDriver::~CWspEventDriver(void)
	?AddBody@CDriverTrans@@QAEXAAVMHTTPDataSupplier@@@Z @ 5 NONAME ; void CDriverTrans::AddBody(class MHTTPDataSupplier &)
	?AddHeaderL@CDriverTrans@@QAEXVRStringF@@W4THdrValType@1@VRString@@@Z @ 6 NONAME ; void CDriverTrans::AddHeaderL(class RStringF, enum CDriverTrans::THdrValType, class RString)
	?AddHeaderWithParamL@CDriverTrans@@QAEXVRStringF@@W4THdrValType@1@VRString@@012@Z @ 7 NONAME ; void CDriverTrans::AddHeaderWithParamL(class RStringF, enum CDriverTrans::THdrValType, class RString, class RStringF, enum CDriverTrans::THdrValType, class RString)
	?AddRequestSessionHeaderL@CWspEventDriver@@QAEXVRStringF@@W4THdrValType@CDriverTrans@@VRString@@@Z @ 8 NONAME ; void CWspEventDriver::AddRequestSessionHeaderL(class RStringF, enum CDriverTrans::THdrValType, class RString)
	?AddRequestSessionHeaderWithParamL@CWspEventDriver@@QAEXVRStringF@@W4THdrValType@CDriverTrans@@VRString@@012@Z @ 9 NONAME ; void CWspEventDriver::AddRequestSessionHeaderWithParamL(class RStringF, enum CDriverTrans::THdrValType, class RString, class RStringF, enum CDriverTrans::THdrValType, class RString)
	?Cancel@CDriverTrans@@QAEXXZ @ 10 NONAME ; void CDriverTrans::Cancel(void)
	?CleanUp@CDriverDataSupplier@@SAXPAX@Z @ 11 NONAME ; void CDriverDataSupplier::CleanUp(void *)
	?Close@CDriverTrans@@QAEXXZ @ 12 NONAME ; void CDriverTrans::Close(void)
	?CreateItemL@CEventCallbackFilter@@MAE?AVTStoredItemBase@@ABVTDesC16@@0@Z @ 13 NONAME ; class TStoredItemBase CEventCallbackFilter::CreateItemL(class TDesC16 const &, class TDesC16 const &)
	?DumpResponseBody@CDriverTrans@@QAEXAAVMConsoleDumper@@@Z @ 14 NONAME ; void CDriverTrans::DumpResponseBody(class MConsoleDumper &)
	?DumpResponseHeadersL@CDriverTrans@@QAEXAAVMConsoleDumper@@@Z @ 15 NONAME ; void CDriverTrans::DumpResponseHeadersL(class MConsoleDumper &)
	?DumpSessionHeadersL@CWspEventDriver@@QAEXAAVMConsoleDumper@@@Z @ 16 NONAME ; void CWspEventDriver::DumpSessionHeadersL(class MConsoleDumper &)
	?FetchFromItemStore@CEventCallbackFilter@@IBEHABVTDesC16@@AAVTStoredItemBase@@@Z @ 17 NONAME ; int CEventCallbackFilter::FetchFromItemStore(class TDesC16 const &, class TStoredItemBase &) const
	?FlushItemStore@CEventCallbackFilter@@IAEXXZ @ 18 NONAME ; void CEventCallbackFilter::FlushItemStore(void)
	?GetBody@CDriverTrans@@QAEAAVMHTTPDataSupplier@@XZ @ 19 NONAME ; class MHTTPDataSupplier & CDriverTrans::GetBody(void)
	?GetConnectionProperties@CWspEventDriver@@QAEXAAVRStringF@@0AAH11001@Z @ 20 NONAME ; void CWspEventDriver::GetConnectionProperties(class RStringF &, class RStringF &, int &, int &, int &, class RStringF &, class RStringF &, int &)
	?GetHeaderL@CDriverTrans@@QAEHVRStringF@@AAW4THdrValType@1@AAVRString@@H@Z @ 21 NONAME ; int CDriverTrans::GetHeaderL(class RStringF, enum CDriverTrans::THdrValType &, class RString &, int)
	?GetStatusCode@CDriverTrans@@QAEHXZ @ 22 NONAME ; int CDriverTrans::GetStatusCode(void)
	?LookUpItem@CEventCallbackFilter@@MBEHVTStoredItemBase@@AAVTPtrC16@@@Z @ 23 NONAME ; int CEventCallbackFilter::LookUpItem(class TStoredItemBase, class TPtrC16 &) const
	?MCIS_Reserved@CEventCallbackFilter@@MAEXXZ @ 24 NONAME ; void CEventCallbackFilter::MCIS_Reserved(void)
	?MoreRequestBodyDataL@CDriverTrans@@QAEXXZ @ 25 NONAME ; void CDriverTrans::MoreRequestBodyDataL(void)
	?NewL@CDriverDataSupplier@@SAPAV1@AAVCChatEngine@@@Z @ 26 NONAME ; class CDriverDataSupplier * CDriverDataSupplier::NewL(class CChatEngine &)
	?NewL@CDriverTrans@@SAPAV1@VRHTTPSession@@VRStringF@@VTUriC8@@AAVMDriverTransObs@@AAVMHTTPTransactionCallback@@ABVTDesC16@@@Z @ 27 NONAME ; class CDriverTrans * CDriverTrans::NewL(class RHTTPSession, class RStringF, class TUriC8, class MDriverTransObs &, class MHTTPTransactionCallback &, class TDesC16 const &)
	?NewL@CWspEventDriver@@SAPAV1@AAVCEventCallbackFilter@@ABVTDesC16@@@Z @ 28 NONAME ; class CWspEventDriver * CWspEventDriver::NewL(class CEventCallbackFilter &, class TDesC16 const &)
	?OpenTransactionL@CWspEventDriver@@QAEPAVCDriverTrans@@VRStringF@@VTUriC8@@ABVTDesC16@@@Z @ 29 NONAME ; class CDriverTrans * CWspEventDriver::OpenTransactionL(class RStringF, class TUriC8, class TDesC16 const &)
	?Reset@CWspEventDriver@@QAEHXZ @ 30 NONAME ; int CWspEventDriver::Reset(void)
	?SessionConnectL@CWspEventDriver@@QAEXXZ @ 31 NONAME ; void CWspEventDriver::SessionConnectL(void)
	?SessionDisconnectL@CWspEventDriver@@QAEXXZ @ 32 NONAME ; void CWspEventDriver::SessionDisconnectL(void)
	?SetClientMessageSizeL@CWspEventDriver@@QAEXK@Z @ 33 NONAME ; void CWspEventDriver::SetClientMessageSizeL(unsigned long)
	?SetConnectionPropertiesL@CWspEventDriver@@QAEXVRStringF@@0HHH00H@Z @ 34 NONAME ; void CWspEventDriver::SetConnectionPropertiesL(class RStringF, class RStringF, int, int, int, class RStringF, class RStringF, int)
	?SetMethodMORL@CWspEventDriver@@QAEXK@Z @ 35 NONAME ; void CWspEventDriver::SetMethodMORL(unsigned long)
	?SetServerMessageSizeL@CWspEventDriver@@QAEXK@Z @ 36 NONAME ; void CWspEventDriver::SetServerMessageSizeL(unsigned long)
	?SetTransConverter@CEventCallbackFilter@@QAEXAAVMTransConverter@@@Z @ 37 NONAME ; void CEventCallbackFilter::SetTransConverter(class MTransConverter &)
	?SetUseAcknowledgementsL@CWspEventDriver@@QAEXXZ @ 38 NONAME ; void CWspEventDriver::SetUseAcknowledgementsL(void)
	?SetUseSuspendResumeL@CWspEventDriver@@QAEXXZ @ 39 NONAME ; void CWspEventDriver::SetUseSuspendResumeL(void)
	?StoreItemL@CEventCallbackFilter@@MAEXABVTDesC16@@VTStoredItemBase@@@Z @ 40 NONAME ; void CEventCallbackFilter::StoreItemL(class TDesC16 const &, class TStoredItemBase)
	?StringPool@CWspEventDriver@@QAE?AVRStringPool@@XZ @ 41 NONAME ; class RStringPool CWspEventDriver::StringPool(void)
	?SubmitL@CDriverTrans@@QAEXXZ @ 42 NONAME ; void CDriverTrans::SubmitL(void)
	?Trans@CDriverTrans@@QBE?AVRHTTPTransaction@@XZ @ 43 NONAME ; class RHTTPTransaction CDriverTrans::Trans(void) const
	?TransId@CDriverTrans@@QBEABVTDesC16@@XZ @ 44 NONAME ; class TDesC16 const & CDriverTrans::TransId(void) const

